@@ -8,15 +8,7 @@ function(x = Sys.Date(),
   
   start <- floor_date( x, unit = "month" )
   stop  <- ceiling_date( x, unit = "month" ) - days(1)
-  sequence <- seq.Date(from = start, to = stop, by = "day")
-  
-  out   <- list(start    = start,
-                end      = stop,                
-                sequence = sequence,
-                length   =  length(sequence),
-                values = paste("This month from", x))
-  
-  class(out) <- "tpr"
+  out   <- custom_period(start, stop)
   
   part <- match.arg(part)
   
