@@ -64,3 +64,8 @@ period1 %left_out% period2  # получить даты из period1 котор
 period1 %right_in% period2  # получить даты из period2 которые входят в period1
 period1 %right_out% period2 # получить даты из period2 которые не входят в period2
 
+## ---- echo=TRUE----------------------------------------------------------
+dates <- c("2019-09-11", "2019-09-02", "2019-10-11", "2019-08-30")
+dates_tpr <- as_timeperiod(dates)
+dates_tpr
+
